Jido.Chat.Discord.FetchOptions (Jido Chat Discord v1.0.0)

Copy Markdown View Source

Typed options for Discord history fetch operations.

Summary

Functions

Builds typed fetch options from keyword, map, or struct input.

Returns the Zoi schema for fetch options.

Builds transport-level options consumed by Discord transport clients.

Types

t()

@type t() :: %Jido.Chat.Discord.FetchOptions{
  cursor: nil | nil | binary(),
  direction: :forward | :backward,
  limit: integer(),
  nostrum_channel_api: nil | nil | any(),
  transport: any()
}

Functions

new(opts)

Builds typed fetch options from keyword, map, or struct input.

schema()

Returns the Zoi schema for fetch options.

transport_opts(opts)

@spec transport_opts(t()) :: keyword()

Builds transport-level options consumed by Discord transport clients.