In-memory event buffer used by Discord gateway listener integrations.
This buffer is bridge-scoped and can be used as a pull source via
pop_events/2 for Jido.Chat.Discord.GatewayWorker.
Summary
Functions
Returns a specification to start this module under a supervisor.
Types
@type state() :: %{ bridge_id: String.t(), queue: :queue.queue(term()), queue_size: non_neg_integer(), max_events: pos_integer() }
Functions
Returns a specification to start this module under a supervisor.
See Supervisor.
@spec pop_events(String.t(), pos_integer()) :: [term()]
@spec start_link(keyword()) :: GenServer.on_start()