Jido.Chat.Discord.SendOptions (Jido Chat Discord v1.0.0)

Copy Markdown View Source

Typed options for Discord send_message/3.

Summary

Functions

Builds typed send options from keyword, map, or struct input.

Returns the Zoi schema for send options.

Builds transport-level options consumed by Discord transport clients.

Types

t()

@type t() :: %Jido.Chat.Discord.SendOptions{
  allowed_mentions: nil | nil | any(),
  components: nil | nil | any(),
  embeds: nil | nil | any(),
  message_reference: nil | nil | any(),
  nostrum_message_api: nil | nil | any(),
  transport: any(),
  tts: nil | nil | boolean()
}

Functions

new(opts)

Builds typed send options from keyword, map, or struct input.

schema()

Returns the Zoi schema for send options.

transport_opts(opts)

@spec transport_opts(t()) :: keyword()

Builds transport-level options consumed by Discord transport clients.